==> tuia-client-0.4.2-20180725.093555-2-sources.jar: cn/com/tuia/advert/zk/path/AdvertZkPathConstant.java <==
package cn.com.tuia.advert.zk.path;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年03月15日 18:22
 * @descript: 广告配置在zk上的路径
 * @version: 1.0
 */
public interface AdvertZkPathConstant {

    String SINGLE_REPEAT_DAYS_PATH = "/single_repeat_days_path";

    String ES_ON_OFF_PATH = "/es_on_off_path";

    String ADVERT_TURNS_PUT = "/advert_turns_put";

    String ADVERT_TURNS_PUT_PROPORTION = "/advert_turns_put_proportion";

    String APP_PRIVILEGE_PATH = "/app_privilege_path";

    //oCPC启用的效果pv次数配置路径
    String OCPC_ENABLE_COUNT_PATH = "/ocpc_enable_count_path";

    //oCPC最低转换出价配置路径
    String OCPC_CONVERT_MIN_PRICE_PATH = "/ocpc_convert_min_price_path";

    //oCPC最低点击出价配置路径
    String OCPC_CLICK_MIN_PRICE_PATH = "/ocpc_click_min_price";

    //用户领取次数开启素材过滤
    String MATERIAL_FILTER_CONSUMER_COUNT = "/material_filter_consumer_count";

    //特殊代理商的OCPC底价配置
    String SPECIAL_AGENT_OCPC_MIN_PRICE = "/special_agent_ocpc_min_price";

    //es集群
    String ELASTIC_SEARCH_CLUSTER = "/elasticsearch_cluster";

    //es集群名称
    String ELASTIC_SEARCH_CLUSTER_NAME = "/elasticsearch_cluster_name";

    //重复曝光上限次数
    String MULTIPLE_EXPOSURE_LIMIT_COUNT = "/multiple_exposure_limit_count";

    //兑吧cpc对低价
    String DUIBA_CPC_FLOOR_PRICE = "/duiba_cpc_floor_price";

    //兑吧cpc的折扣率
    String DUIBA_CPC_BID_RATE = "/duiba_cpc_bid_rate";

    //谢谢参与数
    String TUIA_THKS_PARTAKE_COUNT = "/tuia_thks_partake_count";

    //流量分配速率
    String TUIA_FLOW_DISTRIBUTION_RATE = "/tuia_flow_distribution_rate";
    
    //单用户广告主发券上限设置
    String TUIA_ADVERTISER_LAUNCH_LIMIT = "/tuia_advertiser_launch_limit";
    
    //单用户广告主发券间隔
    String TUIA_ADVERTISER_LAUNCH_INTERVAL = "/tuia_advertiser_launch_interval";
}

==> tuia-client-0.4.5-20180827.043125-11-sources.jar: cn/com/tuia/advert/zk/path/AdvertZkPathConstant.java <==
package cn.com.tuia.advert.zk.path;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年03月15日 18:22
 * @descript: 广告配置在zk上的路径
 * @version: 1.0
 */
public interface AdvertZkPathConstant {

    String SINGLE_REPEAT_DAYS_PATH = "/single_repeat_days_path";

    String ES_ON_OFF_PATH = "/es_on_off_path";

    String ADVERT_TURNS_PUT = "/advert_turns_put";

    String ADVERT_TURNS_PUT_PROPORTION = "/advert_turns_put_proportion";

    String APP_PRIVILEGE_PATH = "/app_privilege_path";

    //oCPC启用的效果pv次数配置路径
    String OCPC_ENABLE_COUNT_PATH = "/ocpc_enable_count_path";

    //oCPC最低转换出价配置路径
    String OCPC_CONVERT_MIN_PRICE_PATH = "/ocpc_convert_min_price_path";

    //oCPC最低点击出价配置路径
    String OCPC_CLICK_MIN_PRICE_PATH = "/ocpc_click_min_price";

    //用户领取次数开启素材过滤
    String MATERIAL_FILTER_CONSUMER_COUNT = "/material_filter_consumer_count";

    //特殊代理商的OCPC底价配置
    String SPECIAL_AGENT_OCPC_MIN_PRICE = "/special_agent_ocpc_min_price";

    //es集群
    String ELASTIC_SEARCH_CLUSTER = "/elasticsearch_cluster";

    //es集群名称
    String ELASTIC_SEARCH_CLUSTER_NAME = "/elasticsearch_cluster_name";

    //重复曝光上限次数
    String MULTIPLE_EXPOSURE_LIMIT_COUNT = "/multiple_exposure_limit_count";

    //兑吧cpc对低价
    String DUIBA_CPC_FLOOR_PRICE = "/duiba_cpc_floor_price";

    //兑吧cpc的折扣率
    String DUIBA_CPC_BID_RATE = "/duiba_cpc_bid_rate";

    //谢谢参与数
    String TUIA_THKS_PARTAKE_COUNT = "/tuia_thks_partake_count";

    //流量分配速率
    String TUIA_FLOW_DISTRIBUTION_RATE = "/tuia_flow_distribution_rate";
    
    //单用户广告主发券上限设置
    String TUIA_ADVERTISER_LAUNCH_LIMIT = "/tuia_advertiser_launch_limit";
    
    //单用户广告主发券间隔
    String TUIA_ADVERTISER_LAUNCH_INTERVAL = "/tuia_advertiser_launch_interval";

    //大盘优化-重点扶持扶持广告主列表
    String TUIA_INTENSIVE_ADVERTISER_LIST = "/tuia_intensive_advertiser_list";
    //  dmp测试开关
    String DPM_DATA_OPEN="/tuia.dmp.switch";

    //  dmp测试广告
    String DPM_TEST_DATA="/tuia.dmp.data";
}
